@@ -71,3 +71,24 @@ PCAsimilarity.list <- function (cov.x, cov.y = NULL, ...,
   }
   return(output)
 }
+
+#' @rdname PCAsimilarity
+#' @method PCAsimilarity mcmc_sample
+#' @export
+PCAsimilarity.mcmc_sample <- function (cov.x, cov.y, ..., parallel = FALSE)
+{
+  if (class (cov.y) == "mcmc_sample") {
+    n = dim(cov.x)[1]
+    if(dim(cov.y)[1] != n) stop("samples must be of same size")
+    cov.x <- alply(cov.x, 1)
+    output <- aaply(1:n, 1, function(i) PCAsimilarity(cov.x, 
+                                                      cov.y[i,,], ...)$PCAsimilarity,
+                    .parallel = parallel)
+    output <- as.numeric(output)
+  } else{
+    output <- SingleComparisonMap(alply(cov.x, 1), cov.y,
+                                  function(x, y) PCAsimilarity(x, y, ...),
+                                  parallel = parallel)
+  }
+  return(output)
+}
\ No newline at end of file
